jactorch.nn.cnn.layers
======================

.. automodule:: jactorch.nn.cnn.layers

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Conv1dLayer
      Conv2dLayer
      Conv3dLayer
      ConvNDLayerBase
      Deconv1dLayer
      Deconv2dLayer
      Deconv3dLayer
      DeconvAlgo
      LinearLayer
      MLPLayer
   
   

   
   
   

   
   
   








.. rubric:: Class Conv1dLayer
.. autoclass:: Conv1dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Conv2dLayer
.. autoclass:: Conv2dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Conv3dLayer
.. autoclass:: Conv3dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ConvNDLayerBase
.. autoclass:: ConvNDLayerBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Deconv1dLayer
.. autoclass:: Deconv1dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Deconv2dLayer
.. autoclass:: Deconv2dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Deconv3dLayer
.. autoclass:: Deconv3dLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class DeconvAlgo
.. autoclass:: DeconvAlgo
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class LinearLayer
.. autoclass:: LinearLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MLPLayer
.. autoclass:: MLPLayer
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







